proxy Package
=============

:mod:`proxy` Package
--------------------

.. automodule:: camelot.view.proxy
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`collection_proxy` Module
------------------------------

.. automodule:: camelot.view.proxy.collection_proxy
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`queryproxy` Module
------------------------

.. automodule:: camelot.view.proxy.queryproxy
    :members:
    :undoc-members:
    :show-inheritance:

